@@ -22,8 +22,8 @@
 
 #include "query.h"
 #include "term.h"
-#include "filesearchstore.h"
 #include "advancedqueryparser.h"
+#include "searchstore.h"
 
 #include <QString>
 #include <QStringList>
@@ -36,23 +36,23 @@
 
 using namespace Baloo;
 
-const int defaultLimit = 100000;
+const int defaultLimit = -1;
 
 class Baloo::Query::Private {
 public:
     Private() {
         m_limit = defaultLimit;
         m_offset = 0;
-        m_yearFilter = -1;
-        m_monthFilter = -1;
-        m_dayFilter = -1;
+        m_yearFilter = 0;
+        m_monthFilter = 0;
+        m_dayFilter = 0;
         m_sortingOption = SortAuto;
     }
     Term m_term;
 
     QStringList m_types;
     QString m_searchString;
-    uint m_limit;
+    int m_limit;
     uint m_offset;
 
     int m_yearFilter;
@@ -68,12 +68,6 @@ Query::Query()
 {
 }
 
-Query::Query(const Term& t)
-    : d(new Private)
-{
-    d->m_term = t;
-}
-
 Query::Query(const Query& rhs)
     : d(new Private(*rhs.d))
 {
@@ -84,16 +78,6 @@ Query::~Query()
     delete d;
 }
 
-void Query::setTerm(const Term& t)
-{
-    d->m_term = t;
-}
-
-Term Query::term() const
-{
-    return d->m_term;
-}
-
 void Query::addType(const QString& type)
 {
     d->m_types << type.split(QLatin1Char('/'), QString::SkipEmptyParts);
@@ -197,13 +181,34 @@ void Query::setIncludeFolder(const QString& folder)
     d->m_includeFolder = folder;
 }
 
-
-Q_GLOBAL_STATIC_WITH_ARGS(QSharedPointer<FileSearchStore>, s_fileSearchStore, (new FileSearchStore));
-
 ResultIterator Query::exec()
 {
-    int id = (*s_fileSearchStore)->exec(*this);
-    return ResultIterator(id, &(**s_fileSearchStore));
+    Term term(d->m_term);
+    if (!d->m_types.isEmpty()) {
+        for (const QString& type : qAsConst(d->m_types)) {
+            term = term && Term(QStringLiteral("type"), type);
+        }
+    }
+
+    if (!d->m_includeFolder.isEmpty()) {
+        term = term && Term(QStringLiteral("includefolder"), d->m_includeFolder);
+    }
+
+    if (d->m_yearFilter || d->m_monthFilter || d->m_dayFilter) {
+        QByteArray ba = QByteArray::number(d->m_yearFilter);
+        if (d->m_monthFilter < 10)
+            ba += '0';
+        ba += QByteArray::number(d->m_monthFilter);
+        if (d->m_dayFilter < 10)
+            ba += '0';
+        ba += QByteArray::number(d->m_dayFilter);
+
+        term = term && Term(QStringLiteral("modified"), ba, Term::Equal);
+    }
+
+    SearchStore searchStore;
+    QStringList result = searchStore.exec(term, d->m_offset, d->m_limit, d->m_sortingOption == SortAuto);
+    return ResultIterator(result);
 }
 
 QByteArray Query::toJSON()
@@ -211,32 +216,32 @@ QByteArray Query::toJSON()
     QVariantMap map;
 
     if (!d->m_types.isEmpty())
-        map[QLatin1String("type")] = d->m_types;
+        map[QStringLiteral("type")] = d->m_types;
 
     if (d->m_limit != defaultLimit)
-        map[QLatin1String("limit")] = d->m_limit;
+        map[QStringLiteral("limit")] = d->m_limit;
 
     if (d->m_offset)
-        map[QLatin1String("offset")] = d->m_offset;
+        map[QStringLiteral("offset")] = d->m_offset;
 
     if (!d->m_searchString.isEmpty())
-        map[QLatin1String("searchString")] = d->m_searchString;
+        map[QStringLiteral("searchString")] = d->m_searchString;
 
     if (d->m_term.isValid())
-        map[QLatin1String("term")] = QVariant(d->m_term.toVariantMap());
+        map[QStringLiteral("term")] = QVariant(d->m_term.toVariantMap());
 
     if (d->m_yearFilter >= 0)
-        map[QLatin1String("yearFilter")] = d->m_yearFilter;
+        map[QStringLiteral("yearFilter")] = d->m_yearFilter;
     if (d->m_monthFilter >= 0)
-        map[QLatin1String("monthFilter")] = d->m_monthFilter;
+        map[QStringLiteral("monthFilter")] = d->m_monthFilter;
     if (d->m_dayFilter >= 0)
-        map[QLatin1String("dayFilter")] = d->m_dayFilter;
+        map[QStringLiteral("dayFilter")] = d->m_dayFilter;
 
     if (d->m_sortingOption != SortAuto)
-        map[QLatin1String("sortingOption")] = static_cast<int>(d->m_sortingOption);
+        map[QStringLiteral("sortingOption")] = static_cast<int>(d->m_sortingOption);
 
     if (!d->m_includeFolder.isEmpty())
-        map[QLatin1String("includeFolder")] = d->m_includeFolder;
+        map[QStringLiteral("includeFolder")] = d->m_includeFolder;
 
     QJsonObject jo = QJsonObject::fromVariantMap(map);
     QJsonDocument jdoc;
@@ -251,32 +256,32 @@ Query Query::fromJSON(const QByteArray& arr)
     const QVariantMap map = jdoc.object().toVariantMap();
 
     Query query;
-    query.d->m_types = map[QLatin1String("type")].toStringList();
+    query.d->m_types = map[QStringLiteral("type")].toStringList();
 
-    if (map.contains(QLatin1String("limit")))
-        query.d->m_limit = map[QLatin1String("limit")].toUInt();
+    if (map.contains(QStringLiteral("limit")))
+        query.d->m_limit = map[QStringLiteral("limit")].toUInt();
     else
         query.d->m_limit = defaultLimit;
 
-    query.d->m_offset = map[QLatin1String("offset")].toUInt();
-    query.d->m_searchString = map[QLatin1String("searchString")].toString();
-    query.d->m_term = Term::fromVariantMap(map[QLatin1String("term")].toMap());
+    query.d->m_offset = map[QStringLiteral("offset")].toUInt();
+    query.d->m_searchString = map[QStringLiteral("searchString")].toString();
+    query.d->m_term = Term::fromVariantMap(map[QStringLiteral("term")].toMap());
 
-    if (map.contains(QLatin1String("yearFilter")))
-        query.d->m_yearFilter = map[QLatin1String("yearFilter")].toInt();
-    if (map.contains(QLatin1String("monthFilter")))
-        query.d->m_monthFilter = map[QLatin1String("monthFilter")].toInt();
-    if (map.contains(QLatin1String("dayFilter")))
-        query.d->m_dayFilter = map[QLatin1String("dayFilter")].toInt();
+    if (map.contains(QStringLiteral("yearFilter")))
+        query.d->m_yearFilter = map[QStringLiteral("yearFilter")].toInt();
+    if (map.contains(QStringLiteral("monthFilter")))
+        query.d->m_monthFilter = map[QStringLiteral("monthFilter")].toInt();
+    if (map.contains(QStringLiteral("dayFilter")))
+        query.d->m_dayFilter = map[QStringLiteral("dayFilter")].toInt();
 
-    if (map.contains(QLatin1String("sortingOption"))) {
-        int option = map.value("sortingOption").toInt();
+    if (map.contains(QStringLiteral("sortingOption"))) {
+        int option = map.value(QStringLiteral("sortingOption")).toInt();
         query.d->m_sortingOption = static_cast<SortingOption>(option);
     }
 
 
-    if (map.contains(QLatin1String("includeFolder"))) {
-        query.d->m_includeFolder = map.value("includeFolder").toString();
+    if (map.contains(QStringLiteral("includeFolder"))) {
+        query.d->m_includeFolder = map.value(QStringLiteral("includeFolder")).toString();
     }
 
     return query;
@@ -285,13 +290,13 @@ Query Query::fromJSON(const QByteArray& arr)
 QUrl Query::toSearchUrl(const QString& title)
 {
     QUrl url;
-    url.setScheme(QLatin1String("baloosearch"));
+    url.setScheme(QStringLiteral("baloosearch"));
 
     QUrlQuery urlQuery;
-    urlQuery.addQueryItem(QLatin1String("json"), QString::fromUtf8(toJSON()));
+    urlQuery.addQueryItem(QStringLiteral("json"), QString::fromUtf8(toJSON()));
 
-    if (title.size())
-        urlQuery.addQueryItem(QLatin1String("title"), title);
+    if (!title.isEmpty())
+        urlQuery.addQueryItem(QStringLiteral("title"), title);
 
     url.setQuery(urlQuery);
     return url;
@@ -303,14 +308,14 @@ Query Query::fromSearchUrl(const QUrl& url)
         return Query();
 
     QUrlQuery urlQuery(url);
-    QString jsonString = urlQuery.queryItemValue(QLatin1String("json"), QUrl::FullyDecoded);
+    QString jsonString = urlQuery.queryItemValue(QStringLiteral("json"), QUrl::FullyDecoded);
     return Query::fromJSON(jsonString.toUtf8());
 }
 
 QString Query::titleFromQueryUrl(const QUrl& url)
 {
     QUrlQuery urlQuery(url);
-    return urlQuery.queryItemValue(QLatin1String("title"), QUrl::FullyDecoded);
+    return urlQuery.queryItemValue(QStringLiteral("title"), QUrl::FullyDecoded);
 }
 
 bool Query::operator==(const Query& rhs) const
